==> 0.0.3.tar.gz: lib/nxs_swiper.dart <==
import 'package:flutter/material.dart';

class CustomSlider extends StatefulWidget {
  final List<Widget> pages;
  final Color paginationDotBorderColor;
  final Color paginationDotCurrentBorderColor;

  final Color paginationDotBackgroundColor;
  final Color paginationDotCurrentBackgroundColor;

  final double paginationDotCurrentBorderWidth;
  final double paginationDotBorderWidth;

  final Color nextButtonBackgroundColor;

  final double paginationDotWidth;

  final Widget? nextButton;
  final String nextButtonText;
  final bool hideNextButtonOnFinalPage;

  CustomSlider({
    required this.pages,
    this.paginationDotBackgroundColor = Colors.transparent,
    this.paginationDotCurrentBackgroundColor = Colors.white,
    this.paginationDotBorderColor = Colors.white,
    this.paginationDotCurrentBorderColor = Colors.white,
    this.paginationDotCurrentBorderWidth = 1.0,
    this.paginationDotBorderWidth = 1.0,
    this.nextButtonBackgroundColor = Colors.blueAccent,
    this.paginationDotWidth = 10.0,
    this.nextButton,
    this.nextButtonText = 'Next',
    this.hideNextButtonOnFinalPage = true,
  }) {}
  @override
  State<StatefulWidget> createState() {
    return _CustomSliderState();
  }
}

class _CustomSliderState extends State<CustomSlider> {
  final PageController _controller = PageController();
  var _selectedIndex = 0;

  _getPageIndicator() {
    List<Widget> indicators = [];
    for (var index = 0; index < this.widget.pages.length; index++) {
      indicators.add(Padding(
        padding:
            const EdgeInsets.only(bottom: 24.0, left: 8, right: 8, top: 10),
        child: Container(
          height: this.widget.paginationDotWidth,
          width: this.widget.paginationDotWidth,
          alignment: Alignment.bottomCenter,
          decoration: BoxDecoration(
            color: index == _selectedIndex
                ? this.widget.paginationDotCurrentBackgroundColor
                : this.widget.paginationDotBackgroundColor,
            borderRadius: BorderRadius.circular(50),
            border: Border.all(
                color: index == _selectedIndex
                    ? this.widget.paginationDotCurrentBorderColor
                    : this.widget.paginationDotBorderColor,
                width: (index == _selectedIndex
                    ? this.widget.paginationDotCurrentBorderWidth
                    : this.widget.paginationDotBorderWidth)),
          ),
        ),
      ));
    }
    return Row(
        children: indicators, mainAxisAlignment: MainAxisAlignment.center);
  }

  _getNextButton() {
    if (this.widget.nextButton != null) return this.widget.nextButton;
    var nextButton = Padding(
      padding: const EdgeInsets.only(left: 8.0, right: 14, bottom: 8, top: 8),
      child: Row(
        children: [
          ElevatedButton(
            child: Text(this.widget.nextButtonText),
            onPressed: () {
              _controller.nextPage(
                  duration: Duration(milliseconds: 500),
                  curve: Curves.linearToEaseOut);
            },
            style: ButtonStyle(
              backgroundColor: MaterialStateProperty.all(
                  this.widget.nextButtonBackgroundColor),
            ),
          )
        ],
        mainAxisAlignment: MainAxisAlignment.end,
      ),
    );
    return nextButton;
  }

  _getStackViewChildren() {
    List<Widget> widgets = [
      PageView(
        /// [PageView.scrollDirection] defaults to [Axis.horizontal].
        /// Use [Axis.vertical] to scroll vertically.
        controller: _controller,
        children: this.widget.pages,
        onPageChanged: (pageIndex) {
          setState(() {
            _selectedIndex = pageIndex;
          });
        },
      ),
      _getPageIndicator(),
    ];
    if (!this.widget.hideNextButtonOnFinalPage) {
      widgets.add(_getNextButton());
    }
    return widgets;
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.bottomCenter,
      children: _getStackViewChildren(),
    );
  }
}

==> 0.0.4.tar.gz: lib/nxs_swiper.dart <==
import 'package:flutter/material.dart';

class CustomSlider extends StatefulWidget {
  final List<Widget> pages;
  final Color paginationDotBorderColor;
  final Color paginationDotCurrentBorderColor;
  final Color paginationDotBackgroundColor;
  final Color paginationDotCurrentBackgroundColor;
  final double paginationDotCurrentBorderWidth;
  final double paginationDotBorderWidth;
  final Color nextButtonBackgroundColor;
  final double paginationDotWidth;
  final Widget? nextButton;
  final String nextButtonText;
  final bool hideNextButtonOnFinalPage;
  final bool hideNextButton;
  final Function? nextButtonClick;

  CustomSlider({
    required this.pages,
    this.paginationDotBackgroundColor = Colors.transparent,
    this.paginationDotCurrentBackgroundColor = Colors.white,
    this.paginationDotBorderColor = Colors.white,
    this.paginationDotCurrentBorderColor = Colors.white,
    this.paginationDotCurrentBorderWidth = 1.0,
    this.paginationDotBorderWidth = 1.0,
    this.nextButtonBackgroundColor = Colors.blueAccent,
    this.paginationDotWidth = 10.0,
    this.nextButton,
    this.nextButtonText = 'Next',
    this.hideNextButtonOnFinalPage = true,
    this.hideNextButton = false,
    this.nextButtonClick,
  }) {}
  @override
  State<StatefulWidget> createState() {
    return _CustomSliderState();
  }
}

class _CustomSliderState extends State<CustomSlider> {
  final PageController _controller = PageController();
  var _selectedIndex = 0;

  _getPageIndicator() {
    List<Widget> indicators = [];
    for (var index = 0; index < this.widget.pages.length; index++) {
      indicators.add(Padding(
        padding:
            const EdgeInsets.only(bottom: 24.0, left: 8, right: 8, top: 10),
        child: Container(
          height: this.widget.paginationDotWidth,
          width: this.widget.paginationDotWidth,
          alignment: Alignment.bottomCenter,
          decoration: BoxDecoration(
            color: index == _selectedIndex
                ? this.widget.paginationDotCurrentBackgroundColor
                : this.widget.paginationDotBackgroundColor,
            borderRadius: BorderRadius.circular(50),
            border: Border.all(
                color: index == _selectedIndex
                    ? this.widget.paginationDotCurrentBorderColor
                    : this.widget.paginationDotBorderColor,
                width: (index == _selectedIndex
                    ? this.widget.paginationDotCurrentBorderWidth
                    : this.widget.paginationDotBorderWidth)),
          ),
        ),
      ));
    }
    return Row(
        children: indicators, mainAxisAlignment: MainAxisAlignment.center);
  }

  _getNextButton() {
    if (this.widget.nextButton != null) return this.widget.nextButton;
    var nextButton = Padding(
      padding: const EdgeInsets.only(left: 8.0, right: 14, bottom: 8, top: 8),
      child: Row(
        children: [
          ElevatedButton(
            child: Text(this.widget.nextButtonText),
            onPressed: () {
              _controller.nextPage(
                  duration: Duration(milliseconds: 500),
                  curve: Curves.linearToEaseOut);
              if (this.widget.nextButtonClick != null) {
                this.widget.nextButtonClick!();
              }
            },
            style: ButtonStyle(
              backgroundColor: MaterialStateProperty.all(
                  this.widget.nextButtonBackgroundColor),
            ),
          )
        ],
        mainAxisAlignment: MainAxisAlignment.end,
      ),
    );
    return nextButton;
  }

  _getStackViewChildren() {
    List<Widget> widgets = [
      PageView(
        /// [PageView.scrollDirection] defaults to [Axis.horizontal].
        /// Use [Axis.vertical] to scroll vertically.
        controller: _controller,
        children: this.widget.pages,
        onPageChanged: (pageIndex) {
          setState(() {
            _selectedIndex = pageIndex;
          });
        },
      ),
      _getPageIndicator(),
    ];
    if (!this.widget.hideNextButton &&
        ((_selectedIndex < this.widget.pages.length - 1) ||
            !this.widget.hideNextButtonOnFinalPage)) {
      widgets.add(_getNextButton());
    }
    return widgets;
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.bottomCenter,
      children: _getStackViewChildren(),
    );
  }
}
